Further Reading — SQLAlchemy 1.4 Documentation

Release: 1.4.27 | Release Date: November 11, 2021

# SQLAlchemy 1.4 Documentation

SQLAlchemy 1.4 / 2.0 Tutorial

This page is part of the SQLAlchemy 1.4 / 2.0 Tutorial.

Previous: Working with Related Objects

# Further Reading

The sections below are the major top-level sections that discuss the concepts in this tutorial in much more detail, as well as describe many more features of each subsystem.

Core Essential Reference

- Working with Engines and Connections

- Schema Definition Language

- SQL Statements and Expressions API

- Column and Data Types

ORM Essential Reference

- Mapper Configuration

- Relationship Configuration

- Using the Session

- Querying Data, Loading Objects